haversine

Function haversine 

pub fn haversine(lon1: f64, lat1: f64, lon2: f64, lat2: f64) -> f64
Calculate the great circle distance in miles between two points on the earth, specified in decimal degrees.